import ImageIcon from "@mui/icons-material/Image";
import PictureAsPdfIcon from "@mui/icons-material/PictureAsPdf";
import { Button } from "@mui/material";
import { filesize } from "filesize";
import React from "react";
import { FileApi, UploadedFile } from "../api/FileApi";
import { AsyncWidget } from "./AsyncWidget";
import { FileViewerDialog } from "../dialogs/FileViewerDialog";

export function UploadedFileWidget(p: { file_id: number }): React.ReactElement {
  const [file, setFile] = React.useState<UploadedFile | null>(null);

  const load = async () => {
    setFile(await FileApi.GetFile(p.file_id));
  };

  return (
    <AsyncWidget
      errMsg="Failed"
      build={() => <UploadedFileWidgetInner file={file!} />}
      loadKey={p.file_id}
      load={load}
    />
  );
}

function UploadedFileWidgetInner(p: {
  file: UploadedFile;
}): React.ReactElement {
  const [open, setOpen] = React.useState(false);
  return (
    <>
      <FileViewerDialog
        open={open}
        file={p.file}
        onClose={() => { setOpen(false); }}
      />
      <Button
        startIcon={
          p.file.mime_type === "application/pdf" ? (
            <PictureAsPdfIcon />
          ) : (
            <ImageIcon />
          )
        }
        onClick={() => { setOpen(true); }}
      >
        {p.file.file_name} ({filesize(p.file.file_size)})
      </Button>
    </>
  );
}
